==> openshift-model-config-6.4.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ClusterNetworkEntryFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterNetworkEntryFluentImpl<A extends ClusterNetworkEntryFluent<A>> extends BaseFluent<A> implements ClusterNetworkEntryFluent<A>{
  public ClusterNetworkEntryFluentImpl() {
  }
  public ClusterNetworkEntryFluentImpl(ClusterNetworkEntry instance) {
    this.withCidr(instance.getCidr()); 
    this.withHostPrefix(instance.getHostPrefix()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String cidr;
  private Integer hostPrefix;
  private Map<String,Object> additionalProperties;
  public String getCidr() {
    return this.cidr;
  }
  public A withCidr(String cidr) {
    this.cidr=cidr; return (A) this;
  }
  public Boolean hasCidr() {
    return this.cidr != null;
  }
  public Integer getHostPrefix() {
    return this.hostPrefix;
  }
  public A withHostPrefix(Integer hostPrefix) {
    this.hostPrefix=hostPrefix; return (A) this;
  }
  public Boolean hasHostPrefix() {
    return this.hostPrefix != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClusterNetworkEntryFluentImpl that = (ClusterNetworkEntryFluentImpl) o;
    if (cidr != null ? !cidr.equals(that.cidr) :that.cidr != null) return false;
    if (hostPrefix != null ? !hostPrefix.equals(that.hostPrefix) :that.hostPrefix != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cidr,  hostPrefix,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cidr != null) { sb.append("cidr:"); sb.append(cidr + ","); }
    if (hostPrefix != null) { sb.append("hostPrefix:"); sb.append(hostPrefix + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/ClusterNetworkEntryFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterNetworkEntryFluentImpl<A extends ClusterNetworkEntryFluent<A>> extends BaseFluent<A> implements ClusterNetworkEntryFluent<A>{
  public ClusterNetworkEntryFluentImpl() {
  }
  public ClusterNetworkEntryFluentImpl(ClusterNetworkEntry instance) {
    if (instance != null) {
      this.withCidr(instance.getCidr());
      this.withHostPrefix(instance.getHostPrefix());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String cidr;
  private Integer hostPrefix;
  private Map<String,Object> additionalProperties;
  public String getCidr() {
    return this.cidr;
  }
  public A withCidr(String cidr) {
    this.cidr=cidr; return (A) this;
  }
  public Boolean hasCidr() {
    return this.cidr != null;
  }
  public Integer getHostPrefix() {
    return this.hostPrefix;
  }
  public A withHostPrefix(Integer hostPrefix) {
    this.hostPrefix=hostPrefix; return (A) this;
  }
  public Boolean hasHostPrefix() {
    return this.hostPrefix != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterNetworkEntryFluentImpl that = (ClusterNetworkEntryFluentImpl) o;
    if (!java.util.Objects.equals(cidr, that.cidr)) return false;

    if (!java.util.Objects.equals(hostPrefix, that.hostPrefix)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cidr,  hostPrefix,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cidr != null) { sb.append("cidr:"); sb.append(cidr + ","); }
    if (hostPrefix != null) { sb.append("hostPrefix:"); sb.append(hostPrefix + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
